@@ -20,7 +20,7 @@
 #	Johannes Bauer <JohannesBauer@gmx.de>
 
 from .BitString import BitString
-from .LZString import LZStringDecompressor
+from .LZString import LZStringDecompressor, LZStringCompressor
 from .Exceptions import LZStringDecompressionException
 
-VERSION = "0.0.1"
+VERSION = "0.0.2"
